@@ -1,21 +1,21 @@
 package Plack::Auth::SSO::CAS;
 
-use Catmandu::Sane;
-use Catmandu::Util qw(:check :is);
+use strict;
+use utf8;
+use Data::Util qw(:check);
 use Authen::CAS::Client;
 use Moo;
 use Plack::Request;
 use Plack::Session;
 use Plack::Auth::SSO::ResponseParser::CAS;
-use namespace::clean;
 
-our $VERSION = "0.012";
+our $VERSION = "0.013";
 
 with "Plack::Auth::SSO";
 
 has cas_url => (
     is => "ro",
-    isa => sub { check_string($_[0]); },
+    isa => sub { is_string($_[0]) or die("cas_url should be string"); },
     required => 1
 );
 has cas => (
@@ -98,6 +98,17 @@ sub to_app {
                 ];
 
             }
+            #e.g. "Can't connect to localhost:8443 (certificate verify failed)"
+            elsif( $r->is_error() ) {
+
+                return [
+                    500,
+                    [ "Content-Type" => "text/html" ],
+                    [ $r->doc() ]
+                ];
+
+            }
+            #$r->is_failure() -> authenticationFailure: return to authentication url
 
         }
 
