@@ -1,11 +1,9 @@
 package Plack::Auth::SSO::ResponseParser;
 
-use Catmandu::Sane;
+use strict;
 use Moo::Role;
 
-our $VERSION = "0.012";
-
-with "Catmandu::Logger";
+our $VERSION = "0.013";
 
 requires "parse";
 
